@@ -13,12 +13,22 @@ $1	swap	swap	default	0 0
 EOT
 }
 
+# Get first usb disk
+usb_device()
+{
+	cd /sys/block
+	for i in sd* sda ; do
+		grep -qs 1 $i/removable && break
+	done
+	echo $i
+}
+
 # Default user account without password (uid=1000). In live mode the option
 # user=name can be used, but user must be added before home= to have home dir.
 # This option is not handled by a loop and case like others and has no
 # effect on an installed system.
 if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
-	if grep -q "user=" /proc/cmdline; then
+	if fgrep -q "user=" /proc/cmdline; then
 		USER=`cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/'`
 		# Avoid usage of an existing system user or root.
 		if grep -q ^$USER /etc/passwd; then
@@ -72,9 +82,9 @@ do
 			# user home dir. Note: home=usb is a shorter and easier way to
 			# have home=/dev/sda1.
 			DEVICE=${opt#home=}
-			[ "$DEVICE" = "usb" ] && DEVICE=sda1
+			[ "$DEVICE" = "usb" ] && DEVICE="$(usb_device)1"
 			echo "Home has been specified to $DEVICE..."
-			DEVID=`/sbin/blkid | sed 'p;s/"//g' | grep "$DEVICE" | sed 's/:.*//;q'`
+			DEVID=`/sbin/blkid | sed 'p;s/"//g' | fgrep "$DEVICE" | sed 's/:.*//;q'`
 			if [ -z "$DEVID" ]; then
 				USBDELAY=`cat /sys/module/usb_storage/parameters/delay_use`
 				USBDELAY=$((2+$USBDELAY))
@@ -85,14 +95,17 @@ do
 			DEVID=$DEVICE
 			if [ -x /sbin/blkid ]; then
 				# Can be a label, uuid, type or devname. DEVID gives us first: /dev/name.
-				DEVID=`/sbin/blkid | sed 'p;s/"//g' | grep "$DEVICE" | sed 's/:.*//;q'`
+				DEVID=`/sbin/blkid | sed 'p;s/"//g' | fgrep "$DEVICE" | sed 's/:.*//;q'`
 			fi
 			DEVID=${DEVID##*/}
-			if [ -n "$DEVID" ] && grep -q "$DEVID" /proc/partitions ; then
+			if [ -n "$DEVID" ] && fgrep -q "$DEVID" /proc/partitions ; then
 				echo "Mounting /home on /dev/$DEVID... "
 				[ -d /home/$USER ] && mv /home/$USER /tmp/$USER-files
 				mount /dev/$DEVID /home -o uid=1000,gid=100 2>/dev/null \
 					|| mount /dev/$DEVID /home
+				case "$(/sbin/blkid | grep /dev/$DEVID:)" in
+				*\"ntfs\"*|*\"vfat\"*) mount.posixovl /home ;;
+				esac					
 				# Check if swap file must be generated in /home: swap=size (Mb).
 				# This option is only used within home=device.
 				if grep -q "swap=[1-9]*" /proc/cmdline; then
